powered by
The utrunmnt function uses the moment generating function to compute any order of moment for the truncated normal distribution.
utrunmnt
utrunmnt(k, mu = 0, lower = -Inf, upper = Inf, sd = 1)
a numeric value.
Order of moment. It must be a non-negative integer.
Mean of parent normal distribution. Defaults to 0.
Lower limit. Defaults to -Inf.
Upper limit. Defaults to Inf.
Standard deviation of parent normal distribution. Defaults to 1.
Burkardt, J. (2014). The truncated normal distribution, Online document, Available from: https://people.sc.fsu.edu/~jburkardt/presentations/truncated_normal.pdf.
utrunmnt(4, mu = 5, upper = 10) utrunmnt(1, mu = 5, lower = -3, upper = 4, sd = 2)
Run the code above in your browser using DataLab